Continuous functions - Math Help Forum
Description: 1) Consider the formula f(x)=lim(n-->infinity)((x^n)/(1+x^n)). Let D={x:f(x) is an element of R}. Calculate f(x) for all x elements of D and
Keywords: Continuous,functions,continuous, functions

- Register
- Help
- Save?

Results 1 to 5 of 5

# Math Help - Continuous functions

- ###### LinkBack

  - LinkBack URL
  - About LinkBacks

- ###### Thread Tools

  - Show Printable Version
  - Subscribe to this Thread…

- ###### Display

  - Linear Mode
  - Switch to Hybrid Mode
  - Switch to Threaded Mode

1. April 8th 2009, 09:51 PM #1
   noles2188
   Member

   Joined
     Oct 2008
   Posts
     124

   ## Continuous functions

   > 1) Consider the formula f(x)=lim(n-->infinity)((x^n)/(1+x^n)).
   > Let D={x:f(x) is an element of R}. Calculate f(x) for all x elements of D and determine where f: D-->R is continuous.
   > 2) Let f: D-->R and suppose that f(x) greater than equal 0 for all x elements of D. Define sqrt(f)-->R by (sqrt(f))(x) = sqrt(f(x)). If f is continuous at c elements of D, prove that sqrt(f) is continuous at c.

   > Follow Math Help Forum on Facebook and Google+

2. April 9th 2009, 07:59 AM #2
   xalk
   Banned

   Joined
     Mar 2009
   Posts
     256
   Thanks
     1

   > Originally Posted by noles2188
   > 1) Consider the formula f(x)=lim(n-->infinity)((x^n)/(1+x^n)).
   > Let D={x:f(x) is an element of R}. Calculate f(x) for all x elements of D and determine where f: D-->R is continuous.
   > 2) Let f: D-->R and suppose that f(x) greater than equal 0 for all x elements of D. Define sqrt(f)-->R by (sqrt(f))(x) = sqrt(f(x)). If f is continuous at c elements of D, prove that sqrt(f) is continuous at c.
   > We have :f(x)=
   > .................................................. .........................................1
   > AND now we have the following cases:
   > 1) |x|<1 <===> -1<x<1 ,then
   > .
   > 2) x=1 ,then
   > .
   > 3) x>1 ,then
   > .
   > 4) x =-1 ,then
   > oscillates finitely.
   > 5) x<-1 ,then
   > oscillates infinitely.
   > And thus by using (1)
   > For -1<x<1 ,f(x) = 0 and
   > For x=1 , f(x)=1/2.
   > Thus D= (-1,1] = (-1,1)U{1}
   > Next we consider continuity over (-1,1].
   > Let -1<c<1 ,and consider
   > .
   > HENCE f is continuous over (-1,1).
   > But if c=1 ,then f(1)=1/2 ,so we see there is a gap from 0 ,which is the value of f(x) for -1<x<1 , to 1/2 =f(1) and hence the function is not continuous.
   > To prove that:
   > Let, ε=1/4, then for all δ>0 choose ,x=0 ,then |f(x)-f(1)|=|f(0)-f(1)|=|0-1/2|=
   > .
   > Thus
   > .
   > Now to prove : if
   > ,then
   > ,where
   > ,when x belongs to D.
   > For that you must consider the :
   > .................................................. ..................................2
   > Now multiply (2) by
   > and we get:
   > .
   > But
   > ,thus :
   > .................................................. .......................................3
   > And if we want (3) smaller than ε>0 we must have :
   > which is possible since f is continuous at c.
   > Hence sqrt(f) is continuous at c

   > Follow Math Help Forum on Facebook and Google+

3. April 9th 2009, 03:54 PM #3
   Plato
   MHF Contributor

   Joined
     Aug 2006
   Posts
     18,605
   Thanks
     1574
   Awards
     1

   > Originally Posted by noles2188
   > 1) Consider the formula f(x)=lim(n-->infinity)((x^n)/(1+x^n)).
   > Let D={x:f(x) is an element of R}. Calculate f(x) for all x elements of D and determine where f: D-->R is continuous.
   > The answer above is incomplete.
   > That means that
   > .
   > It also means that
   > is continuous on
   > .
   > The mistake above is:
   > .

   > Follow Math Help Forum on Facebook and Google+

4. April 9th 2009, 06:45 PM #4
   xalk
   Banned

   Joined
     Mar 2009
   Posts
     256
   Thanks
     1

   > Originally Posted by Plato
   > The mistake above is:
   > .
   > If |x|>1 ,then x<-1 or x>1 ,but for x=-2 for example the limit of ;
   > is not equal to 1

   > Follow Math Help Forum on Facebook and Google+

5. April 10th 2009, 12:10 AM #5
   Opalg
   MHF Contributor

   Joined
     Aug 2007
   From
     Leeds, UK
   Posts
     4,041
   Thanks
     7

   > Originally Posted by xalk
   > the limit of
   > is not equal to 1
   > Yes it is! The reason is that
   > ; and
   > . So
   > as
   > .

   > Follow Math Help Forum on Facebook and Google+

« Intermediate Value theorem application | Closure, Interior and limit points of finite compliment topology question »

#### Similar Math Help Forum Discussions

1. ###### Continuous functions

   Posted in the Discrete Math Forum
   Replies: 1
   Last Post: May 22nd 2010, 05:29 PM

2. ###### more continuous functions

   Posted in the Differential Geometry Forum
   Replies: 1
   Last Post: October 5th 2009, 11:57 AM

3. ###### continuous functions

   Posted in the Differential Geometry Forum
   Replies: 0
   Last Post: October 4th 2009, 12:47 PM

4. ###### Why are the functions f and g continuous?

   Posted in the Calculus Forum
   Replies: 1
   Last Post: September 3rd 2009, 07:01 PM

5. ###### On continuous functions

   Posted in the Advanced Algebra Forum
   Replies: 1
   Last Post: April 30th 2008, 11:58 PM

#### Search Tags

continuous, functions

View Tag Cloud